@@ -55,26 +55,26 @@
 class KTextDecorator : public Sonnet::SpellCheckDecorator
 {
 public:
-    KTextDecorator(KTextEdit *textEdit);
-    bool isSpellCheckingEnabledForBlock(const QString &textBlock) const Q_DECL_OVERRIDE;
+    explicit KTextDecorator(KTextEdit *textEdit);
+    bool isSpellCheckingEnabledForBlock(const QString &textBlock) const override;
 private:
     KTextEdit *m_textEdit;
 };
 
-class KTextEdit::Private
+class Q_DECL_HIDDEN KTextEdit::Private
 {
 public:
     Private(KTextEdit *_parent)
         : parent(_parent),
-          languagesMenu(Q_NULLPTR),
+          languagesMenu(nullptr),
           customPalette(false),
           spellCheckingEnabled(false),
           findReplaceEnabled(true),
           showTabAction(true),
           showAutoCorrectionButton(false),
-          decorator(0), speller(0), findDlg(0), find(0), repDlg(0), replace(0),
+          decorator(nullptr), speller(nullptr), findDlg(nullptr), find(nullptr), repDlg(nullptr), replace(nullptr),
 #ifdef HAVE_SPEECH
-          textToSpeech(Q_NULLPTR),
+          textToSpeech(nullptr),
 #endif
           findIndex(0), repIndex(0),
           lastReplacedPosition(-1)
@@ -82,9 +82,6 @@ public:
         //Check the default sonnet settings to see if spellchecking should be enabled.
         QSettings settings(QStringLiteral("KDE"), QStringLiteral("Sonnet"));
         spellCheckingEnabled = settings.value(QStringLiteral("checkerEnabledByDefault"), false).toBool();
-#ifdef HAVE_SPEECH
-        textToSpeech = new QTextToSpeech(parent);
-#endif
     }
 
     ~Private()
@@ -174,7 +171,7 @@ void KTextEdit::Private::checkSpelling(bool force)
         backgroundSpellCheck->changeLanguage(spellCheckingLanguage);
     }
     Sonnet::Dialog *spellDialog = new Sonnet::Dialog(
-        backgroundSpellCheck, force ? parent : 0);
+        backgroundSpellCheck, force ? parent : nullptr);
     backgroundSpellCheck->setParent(spellDialog);
     spellDialog->setAttribute(Qt::WA_DeleteOnClose, true);
     spellDialog->activeAutoCorrect(showAutoCorrectionButton);
@@ -366,7 +363,7 @@ void KTextEdit::showSpellConfigDialog(const QString &windowIcon)
         dialog.setLanguage(d->spellCheckingLanguage);
     }
     if (!windowIcon.isEmpty()) {
-        dialog.setWindowIcon(QIcon::fromTheme(windowIcon));
+        dialog.setWindowIcon(QIcon::fromTheme(windowIcon, dialog.windowIcon()));
     }
     if (dialog.exec()) {
         setSpellCheckingLanguage(dialog.language());
@@ -529,7 +526,7 @@ QMenu *KTextEdit::mousePopupMenu()
 {
     QMenu *popup = createStandardContextMenu();
     if (!popup) {
-        return 0;
+        return nullptr;
     }
     connect(popup, SIGNAL(triggered(QAction*)),
             this, SLOT(menuActivated(QAction*)));
@@ -538,7 +535,7 @@ QMenu *KTextEdit::mousePopupMenu()
     if (!isReadOnly()) {
         QList<QAction *> actionList = popup->actions();
         enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
-        QAction *separatorAction = 0L;
+        QAction *separatorAction = nullptr;
         int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
         if (idx < actionList.count()) {
             separatorAction = actionList.at(idx);
@@ -612,8 +609,8 @@ QMenu *KTextEdit::mousePopupMenu()
             findNextAction->setEnabled(false);
             findPrevAction->setEnabled(false);
         } else {
-            findNextAction->setEnabled(d->find != 0);
-            findPrevAction->setEnabled(d->find != 0);
+            findNextAction->setEnabled(d->find != nullptr);
+            findPrevAction->setEnabled(d->find != nullptr);
         }
         popup->addSeparator();
         popup->addAction(findAction);
@@ -647,6 +644,9 @@ void KTextEdit::slotSpeakText()
     } else {
         text = toPlainText();
     }
+    if (!d->textToSpeech) {
+        d->textToSpeech = new QTextToSpeech(this);
+    }
     d->textToSpeech->say(text);
 #endif
 }
@@ -671,14 +671,14 @@ Sonnet::Highlighter *KTextEdit::highlighter() const
     if (d->decorator) {
         return d->decorator->highlighter();
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
 void KTextEdit::clearDecorator()
 {
     delete d->decorator;
-    d->decorator = 0;
+    d->decorator = nullptr;
 }
 
 void KTextEdit::addTextDecorator(Sonnet::SpellCheckDecorator *decorator)
@@ -754,20 +754,20 @@ void KTextEdit::setReadOnly(bool readOnly)
 
     if (readOnly) {
         delete d->decorator;
-        d->decorator = 0;
+        d->decorator = nullptr;
 
         d->customPalette = testAttribute(Qt::WA_SetPalette);
         QPalette p = palette();
-        QColor color = p.color(QPalette::Disabled, QPalette::Background);
+        QColor color = p.color(QPalette::Disabled, QPalette::Window);
         p.setColor(QPalette::Base, color);
-        p.setColor(QPalette::Background, color);
+        p.setColor(QPalette::Window, color);
         setPalette(p);
     } else {
         if (d->customPalette && testAttribute(Qt::WA_SetPalette)) {
             QPalette p = palette();
             QColor color = p.color(QPalette::Normal, QPalette::Base);
             p.setColor(QPalette::Base, color);
-            p.setColor(QPalette::Background, color);
+            p.setColor(QPalette::Window, color);
             setPalette(p);
         } else {
             setPalette(QPalette());
@@ -821,7 +821,7 @@ void KTextEdit::slotDoReplace()
 
     if (d->repDlg->pattern().isEmpty()) {
         delete d->replace;
-        d->replace = 0;
+        d->replace = nullptr;
         ensureCursorVisible();
         return;
     }
@@ -880,7 +880,7 @@ void KTextEdit::slotReplaceNext()
         d->replace->displayFinalDialog();
         d->replace->disconnect(this);
         d->replace->deleteLater(); // we are in a slot connected to m_replace, don't delete it right away
-        d->replace = 0;
+        d->replace = nullptr;
         ensureCursorVisible();
         //or           if ( m_replace->shouldRestart() ) { reinit (w/o FromCursor) and call slotReplaceNext(); }
     } else {
@@ -896,7 +896,7 @@ void KTextEdit::slotDoFind()
     }
     if (d->findDlg->pattern().isEmpty()) {
         delete d->find;
-        d->find = 0;
+        d->find = nullptr;
         return;
     }
     delete d->find;
@@ -925,7 +925,7 @@ void KTextEdit::slotFindNext()
     if (document()->isEmpty()) {
         d->find->disconnect(this);
         d->find->deleteLater(); // we are in a slot connected to m_find, don't delete right away
-        d->find = 0;
+        d->find = nullptr;
         return;
     }
 
@@ -939,7 +939,7 @@ void KTextEdit::slotFindNext()
         d->find->displayFinalDialog();
         d->find->disconnect(this);
         d->find->deleteLater(); // we are in a slot connected to m_find, don't delete right away
-        d->find = 0;
+        d->find = nullptr;
         //or           if ( m_find->shouldRestart() ) { reinit (w/o FromCursor) and call slotFindNext(); }
     } else {
         //m_find->closeFindNextDialog();
